@@ -59,7 +59,7 @@
 #'
 #' @param seed Positive integer.
 #' Specifies the seed before any randomness based code is being run.
-#' If `NULL` no seed is set in the calling environment.
+#' If `NULL` (default) no seed is set in the calling environment.
 #'
 #' @param predict_model Function.
 #' The prediction function used when `model` is not natively supported.
@@ -248,7 +248,7 @@
 #' }
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #'
 #' # Load example data
 #' data("airquality")
@@ -311,15 +311,17 @@
 #'   n_MC_samples = 1e2
 #' )
 #'
-#' # ctree approach
-#' explain4 <- explain(
-#'   model = model,
-#'   x_explain = x_explain,
-#'   x_train = x_train,
-#'   approach = "ctree",
-#'   phi0 = p,
-#'   n_MC_samples = 1e2
-#' )
+#' if (requireNamespace("party", quietly = TRUE)) {
+#'   # ctree approach
+#'   explain4 <- explain(
+#'     model = model,
+#'     x_explain = x_explain,
+#'     x_train = x_train,
+#'     approach = "ctree",
+#'     phi0 = p,
+#'     n_MC_samples = 1e2
+#'   )
+#' }
 #'
 #' # Combined approach
 #' approach <- c("gaussian", "gaussian", "empirical")
@@ -389,6 +391,12 @@
 #'   iterative_args = list(initial_n_coalitions = 10)
 #' )
 #' }
+#' \dontshow{
+#' if (requireNamespace("future", quietly = TRUE)) {
+#'   # R CMD check: make sure any open connections are closed afterward
+#'   if (!inherits(future::plan(), "sequential")) future::plan("sequential")
+#' }
+#' }
 #'
 #' @export
 #'
@@ -436,7 +444,7 @@ explain <- function(model,
                     max_n_coalitions = NULL,
                     group = NULL,
                     n_MC_samples = 1e3,
-                    seed = 1,
+                    seed = NULL,
                     verbose = "basic",
                     predict_model = NULL,
                     get_model_specs = NULL,
@@ -582,6 +590,8 @@ explain <- function(model,
 #'
 #' @inheritParams default_doc_export
 #'
+#' @return Cleaned up version of the output list used for testthat testing
+#'
 #' @export
 #' @keywords internal
 #' @author Lars Henry Berge Olsen, Martin Jullum
@@ -606,8 +616,8 @@ testing_cleanup <- function(output) {
   # Removing the fit times for regression surrogate models
   if ("regression_surrogate" %in% output$internal$parameters$approach) {
     # Deletes the fit_times for approach = regression_surrogate to make tests pass.
-    # In the future we could delete this only when a new argument in explain called testing is TRUE
     output$internal$objects$regression.surrogate_model$pre$mold$blueprint$recipe$fit_times <- NULL
+    output$internal$objects$regression.surrogate_model$fit$fit$elapsed <- NULL
   }
 
   # Delete the saving_path
