@@ -11,6 +11,8 @@
 # increase the number of MC samples. This also applied to
 # modifications to the MC approaches.
 
+skip_on_cran()
+
 # Continuous data -------------------------------------------------------------------------------------------------
 test_that("output_asymmetric_conditional", {
   expect_snapshot_rds(
@@ -21,6 +23,7 @@ test_that("output_asymmetric_conditional", {
       x_train = x_train_numeric,
       approach = "gaussian",
       phi0 = p0,
+      seed = 1,
       asymmetric = TRUE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = NULL,
@@ -40,6 +43,7 @@ test_that("output_asym_cond_reg", {
       approach = "regression_separate",
       regression.model = parsnip::linear_reg(),
       phi0 = p0,
+      seed = 1,
       asymmetric = TRUE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = NULL,
@@ -58,6 +62,7 @@ test_that("output_asym_cond_reg_iterative", {
       approach = "regression_separate",
       regression.model = parsnip::linear_reg(),
       phi0 = p0,
+      seed = 1,
       asymmetric = TRUE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = NULL,
@@ -76,6 +81,7 @@ test_that("output_symmetric_conditional", {
       x_train = x_train_numeric,
       approach = "gaussian",
       phi0 = p0,
+      seed = 1,
       asymmetric = FALSE,
       causal_ordering = list(1:2, 3, 4:5), # Does not matter when asymmetric = TRUE and confounding = NULL
       confounding = NULL,
@@ -94,6 +100,7 @@ test_that("output_symmetric_marginal_independence", {
       x_train = x_train_numeric,
       approach = "independence",
       phi0 = p0,
+      seed = 1,
       asymmetric = FALSE,
       causal_ordering = list(1:5),
       confounding = TRUE,
@@ -112,6 +119,7 @@ test_that("output_symmetric_marginal_gaussian", {
       x_train = x_train_numeric,
       approach = "gaussian",
       phi0 = p0,
+      seed = 1,
       asymmetric = FALSE,
       causal_ordering = list(1:5),
       confounding = TRUE,
@@ -130,6 +138,7 @@ test_that("output_asym_caus_conf_TRUE", {
       x_train = x_train_numeric,
       approach = "gaussian",
       phi0 = p0,
+      seed = 1,
       asymmetric = TRUE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = TRUE,
@@ -149,6 +158,7 @@ test_that("output_asym_caus_conf_FALSE", {
       x_train = x_train_numeric,
       approach = "gaussian",
       phi0 = p0,
+      seed = 1,
       asymmetric = TRUE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = FALSE,
@@ -167,6 +177,7 @@ test_that("output_asym_caus_conf_mix", {
       x_train = x_train_numeric,
       approach = "gaussian",
       phi0 = p0,
+      seed = 1,
       asymmetric = TRUE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = c(TRUE, FALSE, FALSE),
@@ -185,6 +196,7 @@ test_that("output_asym_caus_conf_mix_n_coal", {
       x_train = x_train_numeric,
       approach = "gaussian",
       phi0 = p0,
+      seed = 1,
       asymmetric = TRUE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = c(TRUE, FALSE, FALSE),
@@ -204,6 +216,7 @@ test_that("output_asym_caus_conf_mix_empirical", {
       x_train = x_train_numeric,
       approach = "empirical",
       phi0 = p0,
+      seed = 1,
       asymmetric = TRUE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = c(TRUE, FALSE, FALSE),
@@ -222,6 +235,7 @@ test_that("output_asym_caus_conf_mix_ctree", {
       x_train = x_train_numeric,
       approach = "ctree",
       phi0 = p0,
+      seed = 1,
       asymmetric = TRUE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = c(TRUE, FALSE, FALSE),
@@ -240,6 +254,7 @@ test_that("output_sym_caus_conf_TRUE", {
       x_train = x_train_numeric,
       approach = "gaussian",
       phi0 = p0,
+      seed = 1,
       asymmetric = FALSE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = TRUE,
@@ -259,6 +274,7 @@ test_that("output_sym_caus_conf_FALSE", {
       x_train = x_train_numeric,
       approach = "gaussian",
       phi0 = p0,
+      seed = 1,
       asymmetric = FALSE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = FALSE,
@@ -277,6 +293,7 @@ test_that("output_sym_caus_conf_mix", {
       x_train = x_train_numeric,
       approach = "gaussian",
       phi0 = p0,
+      seed = 1,
       asymmetric = FALSE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = c(TRUE, FALSE, FALSE),
@@ -297,6 +314,7 @@ test_that("output_sym_caus_conf_TRUE_group", {
       x_train = x_train_numeric,
       approach = "gaussian",
       phi0 = p0,
+      seed = 1,
       asymmetric = FALSE,
       causal_ordering = list(1:2, 3),
       confounding = TRUE,
@@ -317,6 +335,7 @@ test_that("output_sym_caus_conf_mix_group", {
       x_train = x_train_numeric,
       approach = "gaussian",
       phi0 = p0,
+      seed = 1,
       asymmetric = FALSE,
       causal_ordering = list(1, 2, 3),
       confounding = c(TRUE, TRUE, FALSE),
@@ -336,6 +355,7 @@ test_that("output_sym_caus_conf_mix_group_iterative", {
       x_train = x_train_numeric,
       approach = "gaussian",
       phi0 = p0,
+      seed = 1,
       asymmetric = FALSE,
       causal_ordering = list(1, 2, 3),
       confounding = c(TRUE, TRUE, FALSE),
@@ -362,6 +382,7 @@ test_that("output_mixed_sym_caus_conf_TRUE", {
       x_train = x_train_mixed,
       approach = "ctree",
       phi0 = p0,
+      seed = 1,
       asymmetric = FALSE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = TRUE,
@@ -380,6 +401,7 @@ test_that("output_mixed_sym_caus_conf_TRUE_iterative", {
       x_train = x_train_mixed,
       approach = "ctree",
       phi0 = p0,
+      seed = 1,
       asymmetric = FALSE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = TRUE,
@@ -399,6 +421,7 @@ test_that("output_mixed_asym_caus_conf_mixed", {
       x_train = x_train_mixed,
       approach = "ctree",
       phi0 = p0,
+      seed = 1,
       asymmetric = TRUE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = c(TRUE, FALSE, FALSE),
@@ -417,6 +440,7 @@ test_that("output_mixed_asym_caus_conf_mixed_2", {
       x_train = x_train_mixed,
       approach = "ctree",
       phi0 = p0,
+      seed = 1,
       asymmetric = TRUE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = c(FALSE, TRUE, TRUE),
@@ -437,6 +461,7 @@ test_that("output_mixed_asym_cond_reg", {
       approach = "regression_separate",
       regression.model = parsnip::linear_reg(),
       phi0 = p0,
+      seed = 1,
       asymmetric = TRUE,
       causal_ordering = list(1:2, 3, 4:5),
       confounding = NULL,
@@ -458,6 +483,7 @@ test_that("output_categorical_asym_causal_mixed_cat", {
       x_train = x_train_categorical,
       approach = "categorical",
       phi0 = p0,
+      seed = 1,
       asymmetric = FALSE,
       causal_ordering = list(3:4, 2, 1),
       confounding = c(TRUE, FALSE, FALSE),
@@ -479,6 +505,7 @@ test_that("output_cat_asym_causal_mixed_cat_ad", {
       x_train = x_train_categorical,
       approach = "categorical",
       phi0 = p0,
+      seed = 1,
       asymmetric = FALSE,
       causal_ordering = list(3:4, 2, 1),
       confounding = c(TRUE, FALSE, FALSE),
@@ -498,6 +525,7 @@ test_that("output_categorical_asym_causal_mixed_ctree", {
       x_train = x_train_categorical,
       approach = "ctree",
       phi0 = p0,
+      seed = 1,
       asymmetric = FALSE,
       causal_ordering = list(3:4, 2, 1),
       confounding = c(TRUE, FALSE, FALSE),
